==> 1.2.3.tar.gz: lib/src/navigator_observers/cruiser_stack_observer.dart <==
import 'dart:collection';
import 'package:cruiser/src/logger/cruiser_logger.dart';
import 'package:flutter/widgets.dart';

/// Experimental! might be removed or changed.
class CruiserStackObserver extends RouteObserver<PageRoute> 
{
    final NavigatorState navigatorState;
    final List<Route> routeStack = [];

    CruiserStackObserver({this.navigatorState,});

    @override
    void didPop(Route route, Route previousRoute) 
    {
        super.didPop(route, previousRoute);
        routeStack.removeLast();
    }

    @override
    void didPush(Route route, Route previousRoute) 
    {
        super.didPush(route, previousRoute);
        routeStack.add(route);
    }

    @override
    void didReplace({Route newRoute, Route oldRoute}) 
    {
        super.didReplace(newRoute: newRoute, oldRoute: oldRoute);
        int oldIndex = routeStack.indexOf(oldRoute);
        routeStack.removeAt(oldIndex);
        routeStack.insert(oldIndex, newRoute);
     }

    @override
    void didRemove(Route removedRoute, Route previousRoute) 
    {
        super.didRemove(removedRoute, previousRoute);
        routeStack.removeWhere((route) => route == removedRoute);
    }

    /// Returns the list of [Route]s represented as a stack of routes currently
    /// push by Navigator.
    ///
    /// Head and tail of list are bottom and top of stack respectively.
    UnmodifiableListView<Route> getRouteStack() 
    {
        final stack = this.routeStack.reversed.toList();
        return UnmodifiableListView(stack);
    }

    /// Returns the list of route names represented as a stack of routes currently
    /// push by Navigator.
    ///
    /// Head and tail of list are bottom and top of stack respectively.
    UnmodifiableListView<String> getRouteNameStack() 
    {
        final stack = this.routeStack.reversed.map((route) => route.settings.name).toList();
        return UnmodifiableListView(stack);
    }

    void prettyPrintStack() 
    {
        if (!CruiserLogger.instance.isLoggerEnabled) 
        {
            print("`AppLogger` should be enabled to print any Cruiser logs.");
        }

        if (this.routeStack.isEmpty) 
        {
            CruiserLogger.instance.info("Navigation stack is empty!");
        } 
        else 
        {
            String printableStack = routeStack.fold("", (prevValue, route) 
            {
                return "$prevValue ${route.isFirst ? "" : "--->"} ${route.settings.name}";
            });

            CruiserLogger.instance.info("Navigation Stack: " + printableStack);
        }
    }
}

==> 2.0.1.tar.gz: lib/src/navigator_observers/cruiser_stack_observer.dart <==
import 'dart:collection';
import 'package:cruiser/src/logger/cruiser_logger.dart';
import 'package:flutter/widgets.dart';

/// Experimental! might be removed or changed.
class CruiserStackObserver extends RouteObserver<PageRoute> 
{
    final NavigatorState? navigatorState;
    final List<Route> routeStack = [];

    CruiserStackObserver({this.navigatorState,});


    @override
    void didPop(Route route, Route? previousRoute) 
    {
        super.didPop(route, previousRoute);
        routeStack.removeLast();
    }

    @override
    void didPush(Route route, Route? previousRoute) 
    {
        super.didPush(route, previousRoute);
        routeStack.add(route);
    }

    @override
    void didReplace({Route? newRoute, Route? oldRoute}) 
    {
        super.didReplace(newRoute: newRoute, oldRoute: oldRoute);

        if(newRoute != null && oldRoute != null)
        {
            int oldIndex = routeStack.indexOf(oldRoute);
            routeStack.removeAt(oldIndex);
            routeStack.insert(oldIndex, newRoute);
        }
     }

    @override
    void didRemove(Route removedRoute, Route? previousRoute) 
    {
        super.didRemove(removedRoute, previousRoute);
        routeStack.removeWhere((route) => route == removedRoute);
    }

    /// Returns the list of [Route]s represented as a stack of routes currently
    /// push by Navigator.
    ///
    /// Head and tail of list are bottom and top of stack respectively.
    UnmodifiableListView<Route> getRouteStack() 
    {
        final stack = this.routeStack.reversed.toList();
        return UnmodifiableListView(stack);
    }

    /// Returns the list of route names represented as a stack of routes currently
    /// push by Navigator.
    ///
    /// Head and tail of list are bottom and top of stack respectively.
    UnmodifiableListView<String?> getRouteNameStack() 
    {
        final stack = this.routeStack.reversed.map((route) => route.settings.name);
        return UnmodifiableListView(stack);
    }

    void prettyPrintStack() 
    {
        if (!CruiserLogger.instance.isLoggerEnabled) 
        {
            print("`AppLogger` should be enabled to print any Cruiser logs.");
        }

        if (this.routeStack.isEmpty) 
        {
            CruiserLogger.instance.info("Navigation stack is empty!");
        } 
        else 
        {
            String printableStack = routeStack.fold("", (prevValue, route) 
            {
                return "$prevValue ${route.isFirst ? "" : "--->"} ${route.settings.name}";
            });

            CruiserLogger.instance.info("Navigation Stack: " + printableStack);
        }
    }
}
